@@ -6,9 +6,9 @@ Type annotations for networkmanager service literal definitions.
 Usage::
 
     ```python
-    from mypy_boto3_networkmanager.literals import ConnectionState
+    from mypy_boto3_networkmanager.literals import ConnectionStateType
 
-    data: ConnectionState = "AVAILABLE"
+    data: ConnectionStateType = "AVAILABLE"
     ```
 """
 import sys
@@ -20,10 +20,10 @@ else:
 
 
 __all__ = (
-    "ConnectionState",
-    "CustomerGatewayAssociationState",
+    "ConnectionStateType",
+    "CustomerGatewayAssociationStateType",
     "DescribeGlobalNetworksPaginatorName",
-    "DeviceState",
+    "DeviceStateType",
     "GetConnectionsPaginatorName",
     "GetCustomerGatewayAssociationsPaginatorName",
     "GetDevicesPaginatorName",
@@ -32,19 +32,19 @@ __all__ = (
     "GetSitesPaginatorName",
     "GetTransitGatewayConnectPeerAssociationsPaginatorName",
     "GetTransitGatewayRegistrationsPaginatorName",
-    "GlobalNetworkState",
-    "LinkAssociationState",
-    "LinkState",
-    "SiteState",
-    "TransitGatewayConnectPeerAssociationState",
-    "TransitGatewayRegistrationState",
+    "GlobalNetworkStateType",
+    "LinkAssociationStateType",
+    "LinkStateType",
+    "SiteStateType",
+    "TransitGatewayConnectPeerAssociationStateType",
+    "TransitGatewayRegistrationStateType",
 )
 
 
-ConnectionState = Literal["AVAILABLE", "DELETING", "PENDING", "UPDATING"]
-CustomerGatewayAssociationState = Literal["AVAILABLE", "DELETED", "DELETING", "PENDING"]
+ConnectionStateType = Literal["AVAILABLE", "DELETING", "PENDING", "UPDATING"]
+CustomerGatewayAssociationStateType = Literal["AVAILABLE", "DELETED", "DELETING", "PENDING"]
 DescribeGlobalNetworksPaginatorName = Literal["describe_global_networks"]
-DeviceState = Literal["AVAILABLE", "DELETING", "PENDING", "UPDATING"]
+DeviceStateType = Literal["AVAILABLE", "DELETING", "PENDING", "UPDATING"]
 GetConnectionsPaginatorName = Literal["get_connections"]
 GetCustomerGatewayAssociationsPaginatorName = Literal["get_customer_gateway_associations"]
 GetDevicesPaginatorName = Literal["get_devices"]
@@ -55,9 +55,13 @@ GetTransitGatewayConnectPeerAssociationsPaginatorName = Literal[
     "get_transit_gateway_connect_peer_associations"
 ]
 GetTransitGatewayRegistrationsPaginatorName = Literal["get_transit_gateway_registrations"]
-GlobalNetworkState = Literal["AVAILABLE", "DELETING", "PENDING", "UPDATING"]
-LinkAssociationState = Literal["AVAILABLE", "DELETED", "DELETING", "PENDING"]
-LinkState = Literal["AVAILABLE", "DELETING", "PENDING", "UPDATING"]
-SiteState = Literal["AVAILABLE", "DELETING", "PENDING", "UPDATING"]
-TransitGatewayConnectPeerAssociationState = Literal["AVAILABLE", "DELETED", "DELETING", "PENDING"]
-TransitGatewayRegistrationState = Literal["AVAILABLE", "DELETED", "DELETING", "FAILED", "PENDING"]
+GlobalNetworkStateType = Literal["AVAILABLE", "DELETING", "PENDING", "UPDATING"]
+LinkAssociationStateType = Literal["AVAILABLE", "DELETED", "DELETING", "PENDING"]
+LinkStateType = Literal["AVAILABLE", "DELETING", "PENDING", "UPDATING"]
+SiteStateType = Literal["AVAILABLE", "DELETING", "PENDING", "UPDATING"]
+TransitGatewayConnectPeerAssociationStateType = Literal[
+    "AVAILABLE", "DELETED", "DELETING", "PENDING"
+]
+TransitGatewayRegistrationStateType = Literal[
+    "AVAILABLE", "DELETED", "DELETING", "FAILED", "PENDING"
+]
